Documentation
¶
Overview ¶
Package certloader contains a certicate loader.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CertLoader ¶
type CertLoader struct {
CertPath string
KeyPath string
AllowAuto bool
Parent logger.Writer
// contains filtered or unexported fields
}
CertLoader is a certificate loader. It watches for changes to the certificate and key files.
func (*CertLoader) Close ¶
func (cl *CertLoader) Close()
Close closes a CertLoader and releases any underlying resources.
func (*CertLoader) GetCertificate ¶
func (cl *CertLoader) GetCertificate(_ *tls.ClientHelloInfo) (*tls.Certificate, error)
GetCertificate returns the certificate for use in a tls.Config.
func (*CertLoader) Initialize ¶
func (cl *CertLoader) Initialize() error
Initialize initializes a CertLoader.
Click to show internal directories.
Click to hide internal directories.