Documentation
¶
Overview ¶
Package recordstore contains utilities to store/retrieve recordings to/from disk.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoSegmentsFound = errors.New("no recording segments found")
ErrNoSegmentsFound is returned when no recording segments have been found.
Functions ¶
func CommonPath ¶
CommonPath returns the common path between all segments with given recording path.
func FindAllPathsWithSegments ¶
FindAllPathsWithSegments returns all paths that have at least one segment.
func PathAddExtension ¶
func PathAddExtension(path string, format conf.RecordFormat) string
PathAddExtension adds the file extension to the path.
Types ¶
type Mtxi ¶
type Mtxi struct {
amp4.FullBox `mp4:"0,extend"`
StreamID [16]byte `mp4:"1,size=8"`
SegmentNumber uint64 `mp4:"2,size=64"`
DTS int64 `mp4:"3,size=64"`
NTP int64 `mp4:"4,size=64"`
}
Mtxi is a MediaMTX segment info.
Click to show internal directories.
Click to hide internal directories.