hls

package
v1.20.1-soundar.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 31 Imported by: 0

Documentation

Overview

Package hls contains a HLS server.

Index

Constants

This section is empty.

Variables

var ErrMuxerNotFound = errors.New("muxer not found")

ErrMuxerNotFound is returned when a muxer is not found.

var ErrSessionNotFound = errors.New("session not found")

ErrSessionNotFound is returned when a session is not found.

Functions

This section is empty.

Types

type Server

type Server struct {
	Address         string
	DumpPackets     bool
	Encryption      bool
	ServerKey       string
	ServerCert      string
	AllowOrigins    []string
	TrustedProxies  conf.IPNetworks
	AlwaysRemux     bool
	Variant         conf.HLSVariant
	SegmentCount    int
	SegmentDuration conf.Duration
	PartDuration    conf.Duration
	SegmentMaxSize  conf.StringSize
	Directory       string
	CDNSecret       string
	ReadTimeout     conf.Duration
	WriteTimeout    conf.Duration
	MuxerCloseAfter conf.Duration
	ExternalCmdPool *externalcmd.Pool
	Metrics         serverMetrics
	PathManager     serverPathManager
	Parent          serverParent
	// contains filtered or unexported fields
}

Server is a HLS server.

func (*Server) APIMuxersGet

func (s *Server) APIMuxersGet(name string) (*defs.APIHLSMuxer, error)

APIMuxersGet implements defs.APIHLSServer.

func (*Server) APIMuxersList

func (s *Server) APIMuxersList() (*defs.APIHLSMuxerList, error)

APIMuxersList implements defs.APIHLSServer.

func (*Server) APISessionsGet

func (s *Server) APISessionsGet(uuid uuid.UUID) (*defs.APIHLSSession, error)

APISessionsGet implements defs.APIHLSServer.

func (*Server) APISessionsKick

func (s *Server) APISessionsKick(uuid uuid.UUID) error

APISessionsKick implements defs.APIHLSServer.

func (*Server) APISessionsList

func (s *Server) APISessionsList() (*defs.APIHLSSessionList, error)

APISessionsList implements defs.APIHLSServer.

func (*Server) Close

func (s *Server) Close()

Close closes the server.

func (*Server) Initialize

func (s *Server) Initialize() error

Initialize initializes the server.

func (*Server) Log

func (s *Server) Log(level logger.Level, format string, args ...any)

Log implements logger.Writer.

func (*Server) PathNotReady

func (s *Server) PathNotReady(pa defs.Path)

PathNotReady is called by pathManager.

func (*Server) PathReady

func (s *Server) PathReady(pa defs.Path)

PathReady is called by pathManager.

Directories

Path Synopsis
Package main contains an utility to download hls.js
Package main contains an utility to download hls.js

Jump to