rtsp

package
v1.20.1-soundar.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 36 Imported by: 0

Documentation

Overview

Package rtsp contains a RTSP server.

Index

Constants

This section is empty.

Variables

var ErrConnNotFound = errors.New("connection not found")

ErrConnNotFound is returned when a connection is not found.

var ErrSessionNotFound = errors.New("session not found")

ErrSessionNotFound is returned when a session is not found.

Functions

This section is empty.

Types

type Server

type Server struct {
	Address             string
	AuthMethods         []auth.VerifyMethod
	DumpPackets         bool
	UDPReadBufferSize   uint
	ReadTimeout         conf.Duration
	WriteTimeout        conf.Duration
	WriteQueueSize      int
	RTSPTransports      conf.RTSPTransports
	RTPAddress          string
	RTCPAddress         string
	MulticastIPRange    string
	MulticastRTPPort    int
	MulticastRTCPPort   int
	Encryption          bool
	ServerCert          string
	ServerKey           string
	RTSPAddress         string
	TrustedProxies      conf.IPNetworks
	Transports          conf.RTSPTransports
	RunOnConnect        string
	RunOnConnectRestart bool
	RunOnDisconnect     string
	ExternalCmdPool     *externalcmd.Pool
	Metrics             serverMetrics
	PathManager         serverPathManager
	Parent              serverParent
	// contains filtered or unexported fields
}

Server is a RTSP server.

func (*Server) APIConnsGet

func (s *Server) APIConnsGet(uuid uuid.UUID) (*defs.APIRTSPConn, error)

APIConnsGet implements defs.APIRTSPServer.

func (*Server) APIConnsList

func (s *Server) APIConnsList() (*defs.APIRTSPConnsList, error)

APIConnsList implements defs.APIRTSPServer.

func (*Server) APISessionsGet

func (s *Server) APISessionsGet(uuid uuid.UUID) (*defs.APIRTSPSession, error)

APISessionsGet implements defs.APIRTSPServer.

func (*Server) APISessionsKick

func (s *Server) APISessionsKick(uuid uuid.UUID) error

APISessionsKick implements defs.APIRTSPServer.

func (*Server) APISessionsList

func (s *Server) APISessionsList() (*defs.APIRTSPSessionList, error)

APISessionsList implements defs.APIRTSPServer.

func (*Server) Close

func (s *Server) Close()

Close closes the server.

func (*Server) Initialize

func (s *Server) Initialize() error

Initialize initializes the server.

func (*Server) Log

func (s *Server) Log(level logger.Level, format string, args ...any)

Log implements logger.Writer.

func (*Server) OnAnnounce

OnAnnounce implements gortsplib.ServerHandlerOnAnnounce.

func (*Server) OnConnClose

func (s *Server) OnConnClose(ctx *gortsplib.ServerHandlerOnConnCloseCtx)

OnConnClose implements gortsplib.ServerHandlerOnConnClose.

func (*Server) OnConnOpen

func (s *Server) OnConnOpen(ctx *gortsplib.ServerHandlerOnConnOpenCtx)

OnConnOpen implements gortsplib.ServerHandlerOnConnOpen.

func (*Server) OnDecodeError

func (s *Server) OnDecodeError(ctx *gortsplib.ServerHandlerOnDecodeErrorCtx)

OnDecodeError implements gortsplib.ServerHandlerOnDecodeError.

func (*Server) OnDescribe

OnDescribe implements gortsplib.ServerHandlerOnDescribe.

func (*Server) OnPacketsLost

func (s *Server) OnPacketsLost(ctx *gortsplib.ServerHandlerOnPacketsLostCtx)

OnPacketsLost implements gortsplib.ServerHandlerOnPacketsLost.

func (*Server) OnPause

OnPause implements gortsplib.ServerHandlerOnPause.

func (*Server) OnPlay

OnPlay implements gortsplib.ServerHandlerOnPlay.

func (*Server) OnRecord

OnRecord implements gortsplib.ServerHandlerOnRecord.

func (*Server) OnRequest

func (s *Server) OnRequest(sc *gortsplib.ServerConn, req *base.Request)

OnRequest implements gortsplib.ServerHandlerOnRequest.

func (*Server) OnResponse

func (s *Server) OnResponse(sc *gortsplib.ServerConn, res *base.Response)

OnResponse implements gortsplib.ServerHandlerOnResponse.

func (*Server) OnSessionClose

func (s *Server) OnSessionClose(ctx *gortsplib.ServerHandlerOnSessionCloseCtx)

OnSessionClose implements gortsplib.ServerHandlerOnSessionClose.

func (*Server) OnSessionOpen

func (s *Server) OnSessionOpen(ctx *gortsplib.ServerHandlerOnSessionOpenCtx)

OnSessionOpen implements gortsplib.ServerHandlerOnSessionOpen.

func (*Server) OnSetup

OnSetup implements gortsplib.ServerHandlerOnSetup.

func (*Server) OnStreamWriteError

func (s *Server) OnStreamWriteError(ctx *gortsplib.ServerHandlerOnStreamWriteErrorCtx)

OnStreamWriteError implements gortsplib.ServerHandlerOnStreamWriteError.

Jump to