Documentation
¶
Overview ¶
Package hls contains a HLS server.
Index ¶
- Variables
- type Server
- func (s *Server) APIMuxersGet(name string) (*defs.APIHLSMuxer, error)
- func (s *Server) APIMuxersList() (*defs.APIHLSMuxerList, error)
- func (s *Server) APISessionsGet(uuid uuid.UUID) (*defs.APIHLSSession, error)
- func (s *Server) APISessionsKick(uuid uuid.UUID) error
- func (s *Server) APISessionsList() (*defs.APIHLSSessionList, error)
- func (s *Server) Close()
- func (s *Server) Initialize() error
- func (s *Server) Log(level logger.Level, format string, args ...any)
- func (s *Server) PathNotReady(pa defs.Path)
- func (s *Server) PathReady(pa defs.Path)
Constants ¶
This section is empty.
Variables ¶
var ErrMuxerNotFound = errors.New("muxer not found")
ErrMuxerNotFound is returned when a muxer is not found.
var ErrSessionNotFound = errors.New("session not found")
ErrSessionNotFound is returned when a session is not found.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
Address string
DumpPackets bool
Encryption bool
ServerKey string
ServerCert string
AllowOrigins []string
TrustedProxies conf.IPNetworks
AlwaysRemux bool
Variant conf.HLSVariant
SegmentCount int
SegmentDuration conf.Duration
PartDuration conf.Duration
SegmentMaxSize conf.StringSize
Directory string
CDNSecret string
ReadTimeout conf.Duration
WriteTimeout conf.Duration
MuxerCloseAfter conf.Duration
ExternalCmdPool *externalcmd.Pool
Metrics serverMetrics
PathManager serverPathManager
Parent serverParent
// contains filtered or unexported fields
}
Server is a HLS server.
func (*Server) APIMuxersGet ¶
func (s *Server) APIMuxersGet(name string) (*defs.APIHLSMuxer, error)
APIMuxersGet implements defs.APIHLSServer.
func (*Server) APIMuxersList ¶
func (s *Server) APIMuxersList() (*defs.APIHLSMuxerList, error)
APIMuxersList implements defs.APIHLSServer.
func (*Server) APISessionsGet ¶
APISessionsGet implements defs.APIHLSServer.
func (*Server) APISessionsKick ¶
APISessionsKick implements defs.APIHLSServer.
func (*Server) APISessionsList ¶
func (s *Server) APISessionsList() (*defs.APIHLSSessionList, error)
APISessionsList implements defs.APIHLSServer.
func (*Server) PathNotReady ¶
PathNotReady is called by pathManager.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package main contains an utility to download hls.js
|
Package main contains an utility to download hls.js |
Click to show internal directories.
Click to hide internal directories.