Documentation
¶
Overview ¶
Package rtsp contains a RTSP server.
Index ¶
- Variables
- type Server
- func (s *Server) APIConnsGet(uuid uuid.UUID) (*defs.APIRTSPConn, error)
- func (s *Server) APIConnsList() (*defs.APIRTSPConnsList, error)
- func (s *Server) APISessionsGet(uuid uuid.UUID) (*defs.APIRTSPSession, error)
- func (s *Server) APISessionsKick(uuid uuid.UUID) error
- func (s *Server) APISessionsList() (*defs.APIRTSPSessionList, error)
- func (s *Server) Close()
- func (s *Server) Initialize() error
- func (s *Server) Log(level logger.Level, format string, args ...any)
- func (s *Server) OnAnnounce(ctx *gortsplib.ServerHandlerOnAnnounceCtx) (*base.Response, error)
- func (s *Server) OnConnClose(ctx *gortsplib.ServerHandlerOnConnCloseCtx)
- func (s *Server) OnConnOpen(ctx *gortsplib.ServerHandlerOnConnOpenCtx)
- func (s *Server) OnDecodeError(ctx *gortsplib.ServerHandlerOnDecodeErrorCtx)
- func (s *Server) OnDescribe(ctx *gortsplib.ServerHandlerOnDescribeCtx) (*base.Response, *gortsplib.ServerStream, error)
- func (s *Server) OnPacketsLost(ctx *gortsplib.ServerHandlerOnPacketsLostCtx)
- func (s *Server) OnPause(ctx *gortsplib.ServerHandlerOnPauseCtx) (*base.Response, error)
- func (s *Server) OnPlay(ctx *gortsplib.ServerHandlerOnPlayCtx) (*base.Response, error)
- func (s *Server) OnRecord(ctx *gortsplib.ServerHandlerOnRecordCtx) (*base.Response, error)
- func (s *Server) OnRequest(sc *gortsplib.ServerConn, req *base.Request)
- func (s *Server) OnResponse(sc *gortsplib.ServerConn, res *base.Response)
- func (s *Server) OnSessionClose(ctx *gortsplib.ServerHandlerOnSessionCloseCtx)
- func (s *Server) OnSessionOpen(ctx *gortsplib.ServerHandlerOnSessionOpenCtx)
- func (s *Server) OnSetup(ctx *gortsplib.ServerHandlerOnSetupCtx) (*base.Response, *gortsplib.ServerStream, error)
- func (s *Server) OnStreamWriteError(ctx *gortsplib.ServerHandlerOnStreamWriteErrorCtx)
Constants ¶
This section is empty.
Variables ¶
var ErrConnNotFound = errors.New("connection not found")
ErrConnNotFound is returned when a connection is not found.
var ErrSessionNotFound = errors.New("session not found")
ErrSessionNotFound is returned when a session is not found.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
Address string
AuthMethods []auth.VerifyMethod
DumpPackets bool
UDPReadBufferSize uint
ReadTimeout conf.Duration
WriteTimeout conf.Duration
WriteQueueSize int
RTSPTransports conf.RTSPTransports
RTPAddress string
RTCPAddress string
MulticastIPRange string
MulticastRTPPort int
MulticastRTCPPort int
Encryption bool
ServerCert string
ServerKey string
RTSPAddress string
TrustedProxies conf.IPNetworks
Transports conf.RTSPTransports
RunOnConnect string
RunOnConnectRestart bool
RunOnDisconnect string
ExternalCmdPool *externalcmd.Pool
Metrics serverMetrics
PathManager serverPathManager
Parent serverParent
// contains filtered or unexported fields
}
Server is a RTSP server.
func (*Server) APIConnsGet ¶
APIConnsGet implements defs.APIRTSPServer.
func (*Server) APIConnsList ¶
func (s *Server) APIConnsList() (*defs.APIRTSPConnsList, error)
APIConnsList implements defs.APIRTSPServer.
func (*Server) APISessionsGet ¶
APISessionsGet implements defs.APIRTSPServer.
func (*Server) APISessionsKick ¶
APISessionsKick implements defs.APIRTSPServer.
func (*Server) APISessionsList ¶
func (s *Server) APISessionsList() (*defs.APIRTSPSessionList, error)
APISessionsList implements defs.APIRTSPServer.
func (*Server) OnAnnounce ¶
OnAnnounce implements gortsplib.ServerHandlerOnAnnounce.
func (*Server) OnConnClose ¶
func (s *Server) OnConnClose(ctx *gortsplib.ServerHandlerOnConnCloseCtx)
OnConnClose implements gortsplib.ServerHandlerOnConnClose.
func (*Server) OnConnOpen ¶
func (s *Server) OnConnOpen(ctx *gortsplib.ServerHandlerOnConnOpenCtx)
OnConnOpen implements gortsplib.ServerHandlerOnConnOpen.
func (*Server) OnDecodeError ¶
func (s *Server) OnDecodeError(ctx *gortsplib.ServerHandlerOnDecodeErrorCtx)
OnDecodeError implements gortsplib.ServerHandlerOnDecodeError.
func (*Server) OnDescribe ¶
func (s *Server) OnDescribe(ctx *gortsplib.ServerHandlerOnDescribeCtx, ) (*base.Response, *gortsplib.ServerStream, error)
OnDescribe implements gortsplib.ServerHandlerOnDescribe.
func (*Server) OnPacketsLost ¶
func (s *Server) OnPacketsLost(ctx *gortsplib.ServerHandlerOnPacketsLostCtx)
OnPacketsLost implements gortsplib.ServerHandlerOnPacketsLost.
func (*Server) OnRequest ¶
func (s *Server) OnRequest(sc *gortsplib.ServerConn, req *base.Request)
OnRequest implements gortsplib.ServerHandlerOnRequest.
func (*Server) OnResponse ¶
func (s *Server) OnResponse(sc *gortsplib.ServerConn, res *base.Response)
OnResponse implements gortsplib.ServerHandlerOnResponse.
func (*Server) OnSessionClose ¶
func (s *Server) OnSessionClose(ctx *gortsplib.ServerHandlerOnSessionCloseCtx)
OnSessionClose implements gortsplib.ServerHandlerOnSessionClose.
func (*Server) OnSessionOpen ¶
func (s *Server) OnSessionOpen(ctx *gortsplib.ServerHandlerOnSessionOpenCtx)
OnSessionOpen implements gortsplib.ServerHandlerOnSessionOpen.
func (*Server) OnSetup ¶
func (s *Server) OnSetup(ctx *gortsplib.ServerHandlerOnSetupCtx) (*base.Response, *gortsplib.ServerStream, error)
OnSetup implements gortsplib.ServerHandlerOnSetup.
func (*Server) OnStreamWriteError ¶
func (s *Server) OnStreamWriteError(ctx *gortsplib.ServerHandlerOnStreamWriteErrorCtx)
OnStreamWriteError implements gortsplib.ServerHandlerOnStreamWriteError.